@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 """Unit test for univention.config_registry.backend."""
 # pylint: disable-msg=C0103,E0611,R0904
 
@@ -78,9 +78,10 @@ class TestConfigRegistry(object):
 
 		assert tmpucr.exists()
 
-	def test_create_error(self, tmpdir):
+	@pytest.mark.parametrize("path",["/", "/does/not/exist"])
+	def test_create_error(self, path, tmpdir):
 		with pytest.raises(SystemExit):
-			ConfigRegistry("/")
+			ConfigRegistry(path)
 
 	def test_load(self, ucr0):
 		"""Load is fluent"""
@@ -195,7 +196,7 @@ class TestConfigRegistry(object):
 
 	def test_dict(self, ucrf):
 		"""Test merged items."""
-		assert dict(ucrf) == dict([('foo', 'LDAP'), ('bar', 'LDAP'), ('baz', 'NORMAL')])
+		assert dict(ucrf) == {'foo': 'LDAP', 'bar': 'LDAP', 'baz': 'NORMAL'}
 
 	def test_items(self, ucrf):
 		"""Test merged items."""
